==> core-1.23.0-sources.jar: software/amazon/awscdk/core/Resource.java <==
package software.amazon.awscdk.core;

/**
 * A construct which represents an AWS resource.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.2 (build 4370756)", date = "2020-02-07T03:00:47.247Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Resource")
public abstract class Resource extends software.amazon.awscdk.core.Construct implements software.amazon.awscdk.core.IResource {

    protected Resource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Resource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Resource(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.core.ResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Resource(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected java.lang.String generatePhysicalName() {
        return this.jsiiCall("generatePhysicalName", java.lang.String.class);
    }

    /**
     * Returns an environment-sensitive token that should be used for the resource's "ARN" attribute (e.g. `bucket.bucketArn`).
     * <p>
     * Normally, this token will resolve to <code>arnAttr</code>, but if the resource is
     * referenced across environments, <code>arnComponents</code> will be used to synthesize
     * a concrete ARN with the resource's physical name. Make sure to reference
     * <code>this.physicalName</code> in <code>arnComponents</code>.
     * <p>
     * EXPERIMENTAL
     * <p>
     * @param arnAttr The CFN attribute which resolves to the ARN of the resource. This parameter is required.
     * @param arnComponents The format of the ARN of this resource. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected java.lang.String getResourceArnAttribute(final java.lang.String arnAttr, final software.amazon.awscdk.core.ArnComponents arnComponents) {
        return this.jsiiCall("getResourceArnAttribute", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(arnAttr, "arnAttr is required"), java.util.Objects.requireNonNull(arnComponents, "arnComponents is required") });
    }

    /**
     * Returns an environment-sensitive token that should be used for the resource's "name" attribute (e.g. `bucket.bucketName`).
     * <p>
     * Normally, this token will resolve to <code>nameAttr</code>, but if the resource is
     * referenced across environments, it will be resolved to <code>this.physicalName</code>,
     * which will be a concrete name.
     * <p>
     * EXPERIMENTAL
     * <p>
     * @param nameAttr The CFN attribute which resolves to the resource's name. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected java.lang.String getResourceNameAttribute(final java.lang.String nameAttr) {
        return this.jsiiCall("getResourceNameAttribute", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(nameAttr, "nameAttr is required") });
    }

    /**
     * Returns a string-encoded token that resolves to the physical name that should be passed to the CloudFormation resource.
     * <p>
     * This value will resolve to one of the following:
     * <p>
     * <ul>
     * <li>a concrete value (e.g. <code>"my-awesome-bucket"</code>)</li>
     * <li><code>undefined</code>, when a name should be generated by CloudFormation</li>
     * <li>a concrete name generated automatically during synthesis, in
     * cross-environment scenarios.</li>
     * </ul>
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected java.lang.String getPhysicalName() {
        return this.jsiiGet("physicalName", java.lang.String.class);
    }

    /**
     * The stack in which this resource is defined.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.core.Stack getStack() {
        return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.core.Resource {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }
    }
}

==> core-1.24.0-sources.jar: software/amazon/awscdk/core/Resource.java <==
package software.amazon.awscdk.core;

/**
 * A construct which represents an AWS resource.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-13T18:53:48.657Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Resource")
public abstract class Resource extends software.amazon.awscdk.core.Construct implements software.amazon.awscdk.core.IResource {

    protected Resource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Resource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Resource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.ResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Resource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.lang.String generatePhysicalName() {
        return this.jsiiCall("generatePhysicalName", java.lang.String.class);
    }

    /**
     * Returns an environment-sensitive token that should be used for the resource's "ARN" attribute (e.g. `bucket.bucketArn`).
     * <p>
     * Normally, this token will resolve to <code>arnAttr</code>, but if the resource is
     * referenced across environments, <code>arnComponents</code> will be used to synthesize
     * a concrete ARN with the resource's physical name. Make sure to reference
     * <code>this.physicalName</code> in <code>arnComponents</code>.
     * <p>
     * EXPERIMENTAL
     * <p>
     * @param arnAttr The CFN attribute which resolves to the ARN of the resource. This parameter is required.
     * @param arnComponents The format of the ARN of this resource. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected @org.jetbrains.annotations.NotNull java.lang.String getResourceArnAttribute(final @org.jetbrains.annotations.NotNull java.lang.String arnAttr, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.ArnComponents arnComponents) {
        return this.jsiiCall("getResourceArnAttribute", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(arnAttr, "arnAttr is required"), java.util.Objects.requireNonNull(arnComponents, "arnComponents is required") });
    }

    /**
     * Returns an environment-sensitive token that should be used for the resource's "name" attribute (e.g. `bucket.bucketName`).
     * <p>
     * Normally, this token will resolve to <code>nameAttr</code>, but if the resource is
     * referenced across environments, it will be resolved to <code>this.physicalName</code>,
     * which will be a concrete name.
     * <p>
     * EXPERIMENTAL
     * <p>
     * @param nameAttr The CFN attribute which resolves to the resource's name. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected @org.jetbrains.annotations.NotNull java.lang.String getResourceNameAttribute(final @org.jetbrains.annotations.NotNull java.lang.String nameAttr) {
        return this.jsiiCall("getResourceNameAttribute", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(nameAttr, "nameAttr is required") });
    }

    /**
     * Returns a string-encoded token that resolves to the physical name that should be passed to the CloudFormation resource.
     * <p>
     * This value will resolve to one of the following:
     * <p>
     * <ul>
     * <li>a concrete value (e.g. <code>"my-awesome-bucket"</code>)</li>
     * <li><code>undefined</code>, when a name should be generated by CloudFormation</li>
     * <li>a concrete name generated automatically during synthesis, in
     * cross-environment scenarios.</li>
     * </ul>
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected @org.jetbrains.annotations.NotNull java.lang.String getPhysicalName() {
        return this.jsiiGet("physicalName", java.lang.String.class);
    }

    /**
     * The stack in which this resource is defined.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Stack getStack() {
        return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.core.Resource {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }
    }
}
